#
# spec file for package python-osprofiler
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname osprofiler
Name:           python-osprofiler
Version:        1.4.0
Release:        3.3
Summary:        OpenStack Profiler Library
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/osprofiler
Source0:        https://pypi.io/packages/source/o/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-WebOb >= 1.2.3
BuildRequires:  python-ceilometerclient >= 2.5.0
BuildRequires:  python-devel
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-oslo.config >= 3.14.0
BuildRequires:  python-oslo.utils >= 3.16.0
BuildRequires:  python-pymongo >= 3.0.2
BuildRequires:  python-python-subunit >= 0.0.18
BuildRequires:  python-six >= 1.9.0
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-WebOb >= 1.2.3
Requires:       python-oslo.config >= 3.14.0
Requires:       python-oslo.utils >= 3.16.0
Requires:       python-six >= 1.9.0
BuildArch:      noarch

%description
OSProfiler provides a tiny but powerful library that is used by
most (soon to be all) OpenStack projects and their python clients. It
provides functionality to be able to generate 1 trace per request, that goes
through all involved services. This trace can then be extracted and used
to build a tree of calls which can be quite handy for a variety of
reasons (for example in isolating cross-project performance issues).

%package doc
Summary:        Documentation for OSProfiler
Group:          Development/Languages/Python
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 2.5.0

%description doc
Documentation for OSProfiler.

%prep
%setup -q -n %{sname}-%{version}

%build
%{py2_build}

%install
%{py2_install}

# generate html docs
%{__python2} setup.py build_sphinx
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%check
%{__python2} setup.py testr

%files
%license LICENSE
%doc README.rst ChangeLog
%{python2_sitelib}/osprofiler
%{python2_sitelib}/*.egg-info
%{_bindir}/osprofiler

%files doc
%license LICENSE
%doc doc/build/html

%changelog
* Tue Aug 30 2016 tbechtold@suse.com
- update to version 1.4.0
  * Remove discover from test-requirements
  * Don't set html_last_updated_fmt without git
  * Add exception type to stop trace info
  * OSprofiler initialization method
  * Fix title of index page
  * Add Ceilometer driver
  * Expose osprofiler middleware as entrypoint
  * Add MongoDB driver
  * Improve unit test coverage
  * Add connection string usage to osprofiler-cli
  * Add tests for mongodb driver
  * doc: Log warning when can't get informaiton from git
  * Fix typos on spec directory
  * Fix typo: 'Olso' to 'Oslo'
  * Add backward compatible drivers structure
  * Add overall profiler stats by operation
* Mon Aug  1 2016 tbechtold@suse.com
- Add _service and switch to upstream spec file
* Wed Apr 27 2016 mmnelemane@suse.com
- Upgraded to version 1.3.0
  * Add hepler to trace sessions
  * Add an error tip when trace_id is not found
  * Add a similar link with reference to similar projects/libraries
  * Continue work on standardizing osprofiler docs
  * Remove dead/broken link to example
  * Updates to doc conf.py to look the same as other projects
  * Clean thread local profiler object after usage
  * Avoid tracing class and static methods
  * Avoid multiple tracing when applying meta or class decorator
  * Remove outdated version
  * Dont claim copyright for future years
  * Use pkg_resources to get version
  * Enable bandit in gate
  * Fallback if git is absent
  * It's unnecessary set deprecate group for option 'enabled'
  * Add CONTRIBUTING.rst
* Sun Feb 28 2016 dmueller@suse.com
- update to 1.2.0:
  * Remove flake8 ignore list in tox.ini
  * run py34 tests before py27 to work around testr bug
  * stop making a copy of options discovered by config generator
  * Make class detection more accurate
  * Disable staticmethods tracing
  * Add fix for static and class methods in @trace_cls
  * Expose X-Trace-* constants
  * Add raw Ceilometer events support to DevStack plugin
  * Use raw data storage for events to collect more info
  * Use oslo.utils reflection and avoid refinding decorated name
  * Move osprofiler tests into osprofiler
  * Consolidate osprofiler options
  * Remove argparse from requirements
  * Add py34 to tox env list
  * Make profiler timestamp json.dumps friendly
  * Replace deprecated library function os.popen() with subprocess
  * Add DevStack plugin
  * Remove Py33 support
  * Make it possible to specify file path as a source for trace
  * Remove support for py26
  * Improve HTML reports performance
  * Fix TracedMeta class
  * Fix a couple of typos in doc strings
  * Fix Ceilometer parser to use events
  * remove python 2.6 trove classifier
  * Add TracedMeta class
  * Update requirements
  * Deprecated tox -downloadcache option removed
  * Fix enable/disable compatibility
  * Add hacking rules & fix hacking issues
* Tue Nov 17 2015 bwiedemann@suse.com
- update to 0.3.1
  * Make api-paste.ini config optional
  * Fix minor typos in the multi-backend specification
  * Spec: Integration Testing
  * Spec: Better DevStack Integration
  * Spec: Multi Backend support
  * Spec: Optional options in api-paste.ini
  * Add specs base structure
  * Update .gitreview for new namespace
  * Fix date parsing when there's not milliseconds in the date
  * Various cleanups
  * Remove version from setup.cfg
  * Stop using intersphinx
  * Rename doc environment to docs
  * Imporve generated trace html
  * Adding a hits to notice operator when trace not found
* Wed Aug 20 2014 tbechtold@suse.com
- Initial version
